package main

import (
	"flag"
	"fmt"
	"log"
	"os"
	"strconv"
	"time"

	"code.chrissexton.org/cws/getaoc"
)

var year = flag.Int("year", time.Now().Year(), "event year")
var sessID = flag.String("session", "", "session id")
var file = flag.String("file", "input.txt", "filename (- for stdout)")

const base = "https://adventofcode.com"

func main() {
	flag.Parse()
	if flag.NArg() < 1 {
		fmt.Fprintln(os.Stderr, "Error: Must provide a day argument.")
		return
	}
	day, _ := strconv.Atoi(flag.Arg(0))

	sess, ok := os.LookupEnv("AOC_SESSION")
	if !ok && *sessID == "" {
		fmt.Fprintln(os.Stderr, "Error: Must provide a session id.")
		return
	}

	if *sessID != "" {
		sess = *sessID
	}

	body, err := getaoc.GetInput(sess, *year, day)
	if err != nil {
		log.Fatal(err)
	}

	if *file == "-" {
		fmt.Println(body)
	} else {
		f, err := os.Create(*file)
		if err != nil {
			panic(err)
		}
		defer f.Close()
		fmt.Fprint(f, body)
	}
}
